'use strict'

// Imports
const env = require("../toolbox").env
const utils = require("../toolbox").utils;
const Queue = require("./queue")
const Differencify = require('differencify');

class Browser {

    constructor() {
        this.browser = null
    }

    async execute(queue) {
        if (queue === null || queue === undefined || !(queue instanceof Queue)) {
            throw "Queue is not valid"
        }
        await Promise.all(queue.methods.map(async config => {
            let path = utils.screenshotDir(config.url)
            const differencify = new Differencify({
                imageSnapshotPath: path,
                debug: true 
            });
            await differencify.launchBrowser(env.config);
            env.moduleSetup(config.setup)
            let page = await differencify.init().newPage()
            await page.setViewPort({ width: config.version.width, height: config.version.height })
            await page.goto(config.url)
            await utils.scrollPage(page)
            await page.screenshot()
                .toMatchSnapshot()
                .close()
                .end();
            await differencify.cleanup()
        }))
    }
}

module.exports = Browser